@@ -29,8 +29,8 @@ import java.nio.file.Paths;
 import java.util.Arrays;
 import java.util.Comparator;
 import java.util.List;
-import java.util.SortedSet;
 import java.util.regex.PatternSyntaxException;
+import java.util.stream.Collectors;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.DefaultParser;
@@ -47,10 +47,11 @@ import org.apache.commons.io.filefilter.RegexFileFilter;
 import org.apache.commons.io.filefilter.WildcardFileFilter;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.rat.config.AddLicenseHeaders;
-import org.apache.rat.license.ILicense;
-import org.apache.rat.license.ILicenseFamily;
 import org.apache.rat.license.LicenseSetFactory.LicenseFilter;
 import org.apache.rat.report.IReportable;
+import org.apache.rat.utils.DefaultLog;
+import org.apache.rat.utils.Log;
+import org.apache.rat.utils.Log.Level;
 import org.apache.rat.walker.ArchiveWalker;
 import org.apache.rat.walker.DirectoryWalker;
 
@@ -104,45 +105,49 @@ public class Report {
      * List the licenses that were used for the run.
      */
     private static final String LIST_LICENSES = "list-licenses";
+
     /**
-     * List the approved families for the run.
+     * List the all families for the run.
      */
-    private static final String LIST_LICENSE_FAMILIES = "list-approved-families";
+    private static final String LIST_FAMILIES = "list-families";
+
+    private static final String LOG_LEVEL = "log-level";
 
     /**
      * Set unstyled XML output
      */
     private static final String XML = "x";
 
-    /*
-     * Format used for listing license families
-     */
-    private static final String LICENSE_FAMILY_FORMAT = "\t%s: %s\n";
 
     /**
-     * Format used for listing licenses.
-     */
-    private static final String LICENSE_FORMAT = "%s:\t%s\n\t\t%s\n";
-
-    /**
-     * Processes the command line and builds a configuration and executes the report.
+     * Processes the command line and builds a configuration and executes the
+     * report.
+     * 
      * @param args the arguments.
      * @throws Exception on error.
      */
     public static void main(String[] args) throws Exception {
         Options opts = buildOptions();
-
         CommandLine cl;
         try {
             cl = new DefaultParser().parse(opts, args);
         } catch (ParseException e) {
-            System.err.println(e.getMessage());
-            System.err.println("Please use the \"--help\" option to see a list of valid commands and options");
+            DefaultLog.INSTANCE.error(e.getMessage());
+            DefaultLog.INSTANCE.error("Please use the \"--help\" option to see a list of valid commands and options");
             System.exit(1);
             return; // dummy return (won't be reached) to avoid Eclipse complaint about possible NPE
                     // for "cl"
         }
 
+        if (cl.hasOption(LOG_LEVEL)) {
+            try {
+                Log.Level level = Log.Level.valueOf(cl.getOptionValue(LOG_LEVEL).toUpperCase());
+                DefaultLog.INSTANCE.setLevel(level);
+            } catch (IllegalArgumentException e) {
+                DefaultLog.INSTANCE.warn(String.format("Invalid Log Level (%s) specified.", cl.getOptionValue(LOG_LEVEL)));
+                DefaultLog.INSTANCE.warn(String.format("Log level set at: %s", DefaultLog.INSTANCE.getLevel()));
+            }
+        }
         if (cl.hasOption(HELP)) {
             printUsage(opts);
         }
@@ -151,21 +156,34 @@ public class Report {
         if (args == null || args.length != 1) {
             printUsage(opts);
         } else {
-            ReportConfiguration configuration = createConfiguration(args[0],cl);
-            configuration.validate(System.err::println);
+            ReportConfiguration configuration = createConfiguration(args[0], cl);
+            configuration.validate(DefaultLog.INSTANCE::error);
 
-            if (cl.hasOption(LIST_LICENSE_FAMILIES)) {
-                listLicenseFamilies(configuration.getLicenseFamilies(LicenseFilter.all), System.out);
+            boolean dryRun = false;
+            
+            if (cl.hasOption(LIST_FAMILIES)) {
+                LicenseFilter f = LicenseFilter.fromText(cl.getOptionValue(LIST_FAMILIES));
+                if (f != LicenseFilter.none) {                        
+                    dryRun = true;
+                    Reporter.listLicenseFamilies(configuration, f);
+                }
             }
             if (cl.hasOption(LIST_LICENSES)) {
-                listLicenses(configuration.getLicenses(LicenseFilter.all), System.out);
+                LicenseFilter f = LicenseFilter.fromText(cl.getOptionValue(LIST_LICENSES));
+                if (f != LicenseFilter.none) {                        
+                    dryRun = true;
+                    Reporter.listLicenses(configuration, f);
+                }
+            }
+            
+            if (!dryRun) {
+                Reporter.report(configuration);
             }
-            Reporter.report(configuration);
         }
     }
 
     static ReportConfiguration createConfiguration(String baseDirectory, CommandLine cl) throws IOException {
-        final ReportConfiguration configuration = new ReportConfiguration();
+        final ReportConfiguration configuration = new ReportConfiguration(DefaultLog.INSTANCE);
 
         if (cl.hasOption('o')) {
             configuration.setOut(new File(cl.getOptionValue('o')));
@@ -202,7 +220,7 @@ public class Report {
             if (cl.hasOption(STYLESHEET_CLI)) {
                 String[] style = cl.getOptionValues(STYLESHEET_CLI);
                 if (style.length != 1) {
-                    System.err.println("please specify a single stylesheet");
+                    DefaultLog.INSTANCE.error("Please specify a single stylesheet");
                     System.exit(1);
                 }
                 configuration.setStyleSheet(() -> Files.newInputStream(Paths.get(style[0])));
@@ -223,20 +241,7 @@ public class Report {
         configuration.setReportable(getDirectory(baseDirectory, configuration));
         return configuration;
     }
-
-    private static void listLicenseFamilies(SortedSet<ILicenseFamily> families, PrintStream out) {
-        out.println("Families:");
-        families.forEach(x -> out.format(LICENSE_FAMILY_FORMAT, x.getFamilyCategory(), x.getFamilyName()));
-        out.println();
-    }
-
-    private static void listLicenses(SortedSet<ILicense> licenses, PrintStream out) {
-        out.println("Licenses:");
-        licenses.forEach(lic -> out.format(LICENSE_FORMAT, lic.getLicenseFamily().getFamilyCategory(),
-                lic.getLicenseFamily().getFamilyName(), lic.getNotes()));
-        out.println();
-    }
-
+    
     /**
      * Creates a filename filter from patterns to exclude.
      * 
@@ -259,22 +264,35 @@ public class Report {
                 // wildcards to give users more choices to configure exclusions
                 orFilter.addFileFilter(new RegexFileFilter(exclusion));
                 orFilter.addFileFilter(new NameFileFilter(exclusion));
-                orFilter.addFileFilter(new WildcardFileFilter(exclusion));
+                orFilter.addFileFilter(WildcardFileFilter.builder().setWildcards(exclusion).get());
             } catch (PatternSyntaxException e) {
-                System.err.println("Will skip given exclusion '" + exclude + "' due to " + e);
+                DefaultLog.INSTANCE.error("Will skip given exclusion '" + exclude + "' due to " + e);
             }
         }
-        System.err.println("Ignored " + ignoredLines + " lines in your exclusion files as comments or empty lines.");
+        DefaultLog.INSTANCE.error("Ignored " + ignoredLines + " lines in your exclusion files as comments or empty lines.");
         return new NotFileFilter(orFilter);
     }
 
     static Options buildOptions() {
-        Options opts = new Options();
+        String licFilterValues = String.join(", ", 
+                Arrays.stream(LicenseFilter.values()).map(LicenseFilter::name).collect(Collectors.toList()));
 
-        Option help = new Option(HELP, "help", false, "Print help for the RAT command line interface and exit");
-        opts.addOption(help);
+        Options opts = new Options()
+        
+        .addOption(
+                Option.builder().hasArg(true).longOpt(LIST_FAMILIES)
+                .desc("List the defined license families (default is none). Valid options are: "+licFilterValues+".")
+                .build())
+        .addOption(
+                Option.builder().hasArg(true).longOpt(LIST_LICENSES)
+                .desc("List the defined licenses (default is none). Valid options are: "+licFilterValues+".")
+                .build())
 
-        Option out = new Option("o", "out", true, "Define the output file where to write report (default is System.out)");
+        .addOption(new Option(HELP, "help", false, "Print help for the RAT command line interface and exit."));
+        
+
+        Option out = new Option("o", "out", true,
+                "Define the output file where to write a report to (default is System.out).");
         opts.addOption(out);
 
         String defaultHandlingText = " By default all approved default licenses are used";
@@ -282,8 +300,6 @@ public class Report {
         opts.addOption(noDefaults);
 
         opts.addOption(null, LICENSES, true, "File names or URLs for license definitions");
-        opts.addOption(null, LIST_LICENSES, false, "List all active licenses");
-        opts.addOption(null, LIST_LICENSE_FAMILIES, false, "List all defined license families");
         opts.addOption(null, SCAN_HIDDEN_DIRECTORIES, false, "Scan hidden directories");
 
         OptionGroup addLicenseGroup = new OptionGroup();
@@ -291,7 +307,8 @@ public class Report {
                 + "By default new files will be created with the license header, "
                 + "to force the modification of existing files use the --force option.";
 
-        // RAT-85/RAT-203: Deprecated! added only for convenience and for backwards compatibility
+        // RAT-85/RAT-203: Deprecated! added only for convenience and for backwards
+        // compatibility
         Option addLicence = new Option(ADD_OLD, "addLicence", false, addLicenseDesc);
         addLicenseGroup.addOption(addLicence);
         Option addLicense = new Option(ADD, "addLicense", false, addLicenseDesc);
@@ -299,7 +316,7 @@ public class Report {
         opts.addOptionGroup(addLicenseGroup);
 
         Option write = new Option(FORCE, "force", false,
-                "Forces any changes in files to be written directly to the source files (i.e. new files are not created)");
+                "Forces any changes in files to be written directly to the source files (i.e. new files are not created).");
         opts.addOption(write);
 
         Option copyright = new Option(COPYRIGHT, "copyright", true,
@@ -321,6 +338,10 @@ public class Report {
         Option dir = new Option("d", "dir", false, "Used to indicate source when using --exclude");
         opts.addOption(dir);
 
+        opts.addOption( Option.builder().argName("level").longOpt(LOG_LEVEL)
+                .hasArgs().desc("sets the log level.  Valid options are: DEBUG, INFO, WARN, ERROR, OFF")
+                .build() );
+        
         OptionGroup outputType = new OptionGroup();
 
         Option xml = new Option(XML, "xml", false, "Output the report in raw XML format.  Not compatible with -s");
@@ -330,6 +351,8 @@ public class Report {
                 "XSLT stylesheet to use when creating the" + " report.  Not compatible with -x");
         outputType.addOption(xslt);
         opts.addOptionGroup(outputType);
+        
+        
 
         return opts;
     }
@@ -365,10 +388,9 @@ public class Report {
     private static IReportable getDirectory(String baseDirectory, ReportConfiguration config) {
         try (PrintStream out = new PrintStream(config.getOutput().get())) {
             File base = new File(baseDirectory);
+            
             if (!base.exists()) {
-                out.print("ERROR: ");
-                out.print(baseDirectory);
-                out.print(" does not exist.\n");
+                config.getLog().log(Level.ERROR, "Directory '"+baseDirectory+"' does not exist");
                 return null;
             }
 
@@ -379,9 +401,7 @@ public class Report {
             try {
                 return new ArchiveWalker(base, config.getInputFileFilter());
             } catch (IOException ex) {
-                out.print("ERROR: ");
-                out.print(baseDirectory);
-                out.print(" is not valid gzip data.\n");
+                config.getLog().log(Level.ERROR, "file '"+baseDirectory+"' is not valid gzip data.");
                 return null;
             }
         } catch (IOException e) {
