@@ -18,11 +18,8 @@
  */
 package org.apache.rat.annotation;
 
-import org.apache.commons.io.IOUtils;
-import org.apache.rat.test.utils.Resources;
-import org.junit.ClassRule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 
 import java.io.BufferedReader;
 import java.io.File;
@@ -31,12 +28,17 @@ import java.io.FileWriter;
 import java.io.IOException;
 import java.io.Writer;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
+import org.apache.commons.io.FileUtils;
+import org.apache.rat.test.utils.Resources;
+import org.apache.rat.utils.DefaultLog;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 public class TestLicenseAppender {
-    @ClassRule
-    public static final TemporaryFolder baseTempFolder = new TemporaryFolder();
+    
+	@TempDir
+    private File baseTempFolder;
+  
 
     private static final String FIRST_LICENSE_LINE = " Licensed to the Apache Software Foundation (ASF) under one";
 
@@ -48,89 +50,46 @@ public class TestLicenseAppender {
         void readFile(BufferedReader r) throws IOException;
     }
 
-    private static String getTemporaryFileWithName(String fileName) throws IOException {
+    private String getTemporaryFileWithName(String fileName) throws IOException {
         if (fileName != null) {
-            return baseTempFolder.newFile(fileName).getAbsolutePath();
-        } else {
-            return baseTempFolder.newFile().getAbsolutePath();
+            return new File(baseTempFolder,fileName).getAbsolutePath();
         }
+        return File.createTempFile("tla", null, baseTempFolder).getAbsolutePath();
     }
 
     private static void createTestFile(String fileName,
                                        FileCreator creator)
             throws IOException {
-        FileWriter w = null;
-        try {
-            creator.createFile(w = new FileWriter(fileName));
-        } finally {
-            IOUtils.closeQuietly(w);
+        try (FileWriter w = new FileWriter(fileName)) {
+            creator.createFile(w);
         }
     }
 
-    private static void tryToDelete(File f) {
-        if (f != null && f.exists() && !f.delete()) {
-            f.deleteOnExit();
-        }
-    }
-
-    private static void commonTestTemplate(String relativeName,
+    private void commonTestTemplate(String relativeName,
                                            FileCreator creator,
                                            NewFileReader reader)
             throws IOException {
         String name = getTemporaryFileWithName(relativeName);
-        try {
+  
             createTestFile(name, creator);
 
             ApacheV2LicenseAppender appender =
-                    new ApacheV2LicenseAppender();
+                    new ApacheV2LicenseAppender(DefaultLog.INSTANCE);
             appender.append(new File(name));
 
-            BufferedReader r = null;
-            try {
-                r = new BufferedReader(new FileReader(name + ".new"));
+            try (BufferedReader r = new BufferedReader(new FileReader(name + ".new"))){
                 reader.readFile(r);
-            } finally {
-                IOUtils.closeQuietly(r);
             }
-        } finally {
-            tryToDelete(new File(name));
-            tryToDelete(new File(name + ".new"));
-        }
+          FileUtils.delete( new File(name+".new"));
+          FileUtils.delete( new File(name));
     }
 
-    private static NewFileReader checkLines(final String firstLine,
-                                            final String secondLine) {
+    private static NewFileReader checkLines(final String ... lines) {
         return new NewFileReader() {
             public void readFile(BufferedReader r) throws IOException {
-                String line = r.readLine();
-                assertEquals("First line is incorrect",
-                        firstLine, line);
-                if (secondLine != null) {
-                    line = r.readLine();
-                    assertEquals("Second line is incorrect",
-                            secondLine, line);
-                }
-            }
-        };
-    }
-
-    private static NewFileReader checkLines(final String firstLine,
-                                            final String secondLine,
-                                            final String thirdLine) {
-        return new NewFileReader() {
-            public void readFile(BufferedReader r) throws IOException {
-                String line = r.readLine();
-                assertEquals("First line is incorrect",
-                        firstLine, line);
-                if (secondLine != null) {
-                    line = r.readLine();
-                    assertEquals("Second line is incorrect",
-                            secondLine, line);
-                }
-                if (thirdLine != null) {
-                    line = r.readLine();
-                    assertEquals("Third line is incorrect",
-                            thirdLine, line);
+                for (int i=0; i<lines.length; i++) {
+                    String line = r.readLine();
+                    assertEquals(lines[i], line, String.format("Line %s is incorrect",i));
                 }
             }
         };
@@ -149,13 +108,12 @@ public class TestLicenseAppender {
         File file = new File(filename);
         file.deleteOnExit();
         ApacheV2LicenseAppender appender =
-                new ApacheV2LicenseAppender();
+                new ApacheV2LicenseAppender(DefaultLog.INSTANCE);
         appender.append(file);
 
         File newFile = new File(filename + ".new");
         newFile.deleteOnExit();
-        assertFalse("No new file should have been written",
-                newFile.exists());
+        assertFalse(newFile.exists(), "No new file should have been written");
     }
 
     @Test
@@ -187,7 +145,7 @@ public class TestLicenseAppender {
                         writer.write("}\n");
                     }
                 },
-                checkLines(commentLine, null));
+                checkLines(commentLine));
     }
 
     @Test
@@ -238,7 +196,7 @@ public class TestLicenseAppender {
                         writer.write("</html>\n");
                     }
                 },
-                checkLines(commentLine, null));
+                checkLines(commentLine));
     }
 
     @Test
@@ -254,7 +212,7 @@ public class TestLicenseAppender {
                         writer.write("}\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -270,7 +228,7 @@ public class TestLicenseAppender {
                         writer.write("}\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -286,7 +244,7 @@ public class TestLicenseAppender {
                         writer.write(" of any importance\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -302,7 +260,7 @@ public class TestLicenseAppender {
                         writer.write("cool = true\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -324,16 +282,16 @@ public class TestLicenseAppender {
                     public void readFile(BufferedReader reader)
                             throws IOException {
                         String line = reader.readLine();
-                        assertEquals("First line is incorrect",
-                                newFirstLine, line);
+                        assertEquals(
+                                newFirstLine, line, "First line is incorrect");
                         while ((line = reader.readLine()) != null) {
                             if (line.length() == 0) {
                                 line = reader.readLine();
                                 break;
                             }
                         }
-                        assertEquals("Package line is incorrect",
-                                firstLine, line);
+                        assertEquals(
+                                firstLine, line, "Package line is incorrect");
                     }
                 });
     }
@@ -351,7 +309,7 @@ public class TestLicenseAppender {
                         writer.write("end\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -383,7 +341,7 @@ public class TestLicenseAppender {
                         writer.write("print \"Hello world\"\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -431,7 +389,7 @@ public class TestLicenseAppender {
                         writer.write("puts \"Hello world\"\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -482,7 +440,7 @@ public class TestLicenseAppender {
                         writer.write("}\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -498,7 +456,7 @@ public class TestLicenseAppender {
                         writer.write("    }\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -515,7 +473,7 @@ public class TestLicenseAppender {
                         writer.write("}\n");
                     }
                 },
-                checkLines(firstLine, null));
+                checkLines(firstLine));
     }
 
     @Test
@@ -542,28 +500,21 @@ public class TestLicenseAppender {
     @Test
     public void fileWithBOM() throws IOException {
         File f = Resources.getResourceFile("violations/FilterTest.cs");
-        try {
-            ApacheV2LicenseAppender appender =
-                    new ApacheV2LicenseAppender();
-            appender.append(f);
+       
+        ApacheV2LicenseAppender appender =
+                new ApacheV2LicenseAppender(DefaultLog.INSTANCE);
+        appender.append(f);
 
-            BufferedReader r = null;
-            try {
-                r = new BufferedReader(new FileReader(f.getAbsolutePath()
-                        + ".new"));
-                assertEquals("/*", r.readLine());
-                String line = null;
-                while ((line = r.readLine()) != null) {
-                    if (line.trim().length() == 0) {
-                        break;
-                    }
+        try (BufferedReader r =  new BufferedReader(new FileReader(f.getAbsolutePath()
+                    + ".new"))) {
+            assertEquals("/*", r.readLine());
+            String line = null;
+            while ((line = r.readLine()) != null) {
+                if (line.trim().length() == 0) {
+                    break;
                 }
-                assertEquals("#if NET_2_0", r.readLine());
-            } finally {
-                IOUtils.closeQuietly(r);
             }
-        } finally {
-            tryToDelete(new File(f.getAbsolutePath() + ".new"));
+            assertEquals("#if NET_2_0", r.readLine());
         }
     }
 
@@ -610,19 +561,8 @@ public class TestLicenseAppender {
                         writer.write("EndProject\n");
                     }
                 },
-                new NewFileReader() {
-                    public void readFile(BufferedReader r) throws IOException {
-                        String line = r.readLine();
-                        assertEquals("First line is incorrect",
-                                firstLine, line);
-                        line = r.readLine();
-                        assertEquals("Second line is incorrect",
-                                secondLine, line);
-                        line = r.readLine();
-                        assertEquals("Third line is incorrect",
-                                thirdLine, line);
-                    }
-                });
+                checkLines(firstLine, secondLine, thirdLine)
+                );
     }
 
     @Test
@@ -663,19 +603,8 @@ public class TestLicenseAppender {
                         writer.write("EndGlobal \n");
                     }
                 },
-                new NewFileReader() {
-                    public void readFile(BufferedReader r) throws IOException {
-                        String line = r.readLine();
-                        assertEquals("First line is incorrect",
-                                firstLine, line);
-                        line = r.readLine();
-                        assertEquals("Second line is incorrect",
-                                secondLine, line);
-                        line = r.readLine();
-                        assertEquals("Third line is incorrect",
-                                thirdLine, line);
-                    }
-                });
+                checkLines(firstLine, secondLine, thirdLine)
+                );
     }
 
     @Test
@@ -718,20 +647,30 @@ public class TestLicenseAppender {
                         writer.write("EndGlobal \n");
                     }
                 },
+                checkLines(firstLine, secondLine, thirdLine, forthLine)
+               );
+    }
+    
+    @Test
+    public void addLicenseMarkdown() throws IOException {
+        String filename = "tmp.md";
+
+        commonTestTemplate(filename, new FileCreator() {
+                    public void createFile(Writer writer)
+                            throws IOException {
+                        writer.write("## This is the first header\n");
+                        writer.write(" * this is a list entry\n");
+                        writer.write(" * this is another list entry\n");
+                        writer.write(" <!-- this is a comment line -->");
+                        writer.write("## This is the second header\n");
+                    }
+                },
                 new NewFileReader() {
                     public void readFile(BufferedReader r) throws IOException {
                         String line = r.readLine();
-                        assertEquals("First line is incorrect",
-                                firstLine, line);
+                        assertEquals(
+                                "<!--", line, "First line is incorrect");
                         line = r.readLine();
-                        assertEquals("Second line is incorrect",
-                                secondLine, line);
-                        line = r.readLine();
-                        assertEquals("Third line is incorrect",
-                                thirdLine, line);
-                        line = r.readLine();
-                        assertEquals("Forth line is incorrect",
-                                forthLine, line);
                     }
                 });
     }
